@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Auth;
-our $VERSION = '0.001';
+our $VERSION = '0.002';
 
 ## "Standard" Auth module
 ##
@@ -106,7 +106,7 @@ sub Cobalt_register {
   my %su = ref $superusers eq 'HASH' ? %{$superusers} : ();
   SERVER: for my $context (keys %su) {
 
-    USER: for my $user (keys $su{$context}) {
+    USER: for my $user (keys %{$su{$context}}) {
       ## Usernames on accesslist automatically get lowercased
       ## per rfc1459 rules, aka CASEMAPPING=rfc1459
       ## (we probably don't even know the server's CASEMAPPING= yet)
